const CACHE_NAME = "cyberpunk-cache-v1";
const OFFLINE_URL = "/offline.html"; // Diese Seite wird angezeigt, wenn offline
const BASE_PATH = "/cpred/";

const urlsToCache = [
  BASE_PATH,
  BASE_PATH + "/offline.html",
  /* CSS-Dateien */
  BASE_PATH + "/assets/css/main.css",
  BASE_PATH + "/assets/css/normalize.css",
  BASE_PATH + "/assets/css/cyberpunk.css",
  /* JS-Dateien */
  BASE_PATH + "/assets/js/materialize.min.js",
  BASE_PATH + "/assets/js/service-worker.js",
  /* PWA-Dateien */
  BASE_PATH + "/assets/manifest.json",
  BASE_PATH + "/assets/img/icon-192.png",
  BASE_PATH + "/assets/img/icon-512.png",
  /* Bilder, Schriften, etc. */
  BASE_PATH + "/assets/fonts/BlenderProBook.woff2",
  BASE_PATH + "/assets/fonts/Cyberpunk.otf",
  BASE_PATH + "/assets/fonts/Oxanium.woff2",
  BASE_PATH + "/assets/img/Netrunner.png",
  BASE_PATH + "/assets/img/Tech.png",
];

// Installations-Event: Dateien werden in den Cache geladen
self.addEventListener("install", (event) => {
  event.waitUntil(
    caches.open(CACHE_NAME).then((cache) => {
      return cache.addAll(urlsToCache);
    })
  );
});

// Fetch-Event: Prüft, ob eine Datei im Cache ist, bevor sie aus dem Netz geladen wird
self.addEventListener("fetch", (event) => {
  event.respondWith(
    caches.match(event.request).then((response) => {
      return response || fetch(event.request).catch(() => {
        return caches.match(OFFLINE_URL); // Falls offline, lade offline.html
      });
    })
  );
});

// Aktivierungs-Event: Löscht alten Cache, wenn sich Dateien geändert haben
self.addEventListener("activate", (event) => {
  event.waitUntil(
    caches.keys().then((cacheNames) => {
      return Promise.all(
        cacheNames.map((cache) => {
          if (cache !== CACHE_NAME) {
            return caches.delete(cache);
          }
        })
      );
    })
  );
});
